========================
Neo 0.13.1 release notes
========================

7th May 2024


This release of Neo contains a lot of improvements to code quality and documentation,
still with a focus on the planned 1.0 release,
together with, as usual, bug fixes and performance improvements in IO modules.

See all `pull requests`_ included in this release and the `list of closed issues`_.

Code and documentation quality
------------------------------

Particular thanks go to Zach McKenzie, who has checked, and rewritten if necessary, every docstring in the project,
to ensure they all have a consistent style.
Zach has also updated and improved the :doc:`../examples/index` in the Sphinx documentation.

The Neo code base contained a lot of ``assert``\s that should be exceptions.
These have all been replaced with appropriate exceptions (again by Zach McKenzie).
A new exception class, :class:`NeoReadWriteError` has been introduced.

Bug fixes and improvements in IO modules
----------------------------------------

Bug fixes and/or improvements have been made to :class:`SpikeGLXIO`, :class:`OpenEphysIO`, :class:`SpikeGadgetsIO`,
:class:`MaxwellIO`, :class:`AxonIO`, :class:`IntanIO`, :class:`TDTIO`, :class:`NeuralynxIO` and :class:`BlackrockIO`.


Acknowledgements
----------------

Thanks to Zach McKenzie, Andrew Davison, Heberto Mayorquin, Alessio Buccino, Samuel Garcia, Peter N. Steinmetz,
Aitor Morales-Gregorio, Greg Knoll, Chris Halcrow and Szonja Weigl for their contributions to this release.

.. generated with git shortlog --since=2024-02-02 -sne then checking Github for PRs merged since the last release but with commits before then

.. _`list of closed issues`: https://github.com/NeuralEnsemble/python-neo/issues?q=is%3Aissue+milestone%3A0.13.1+is%3Aclosed
.. _`pull requests`: https://github.com/NeuralEnsemble/python-neo/pulls?q=is%3Apr+is%3Aclosed+merged%3A%3E2024-02-02+milestone%3A0.13.1
.. _`examples gallery`: https://neo.readthedocs.io/en/latest/examples/
